pub enum Format {
Gif,
Jpeg,
Json,
Mvt,
Mlt,
Png,
Webp,
Avif,
}Variants
Implementations
Sourceimpl Format
impl Format
Sourcepub const IMAGE_FORMATS: &[Self]
pub const IMAGE_FORMATS: &[Self]
All image formats.
pub fn parse(value: &str) -> Option<Self>
Sourcepub fn metadata_format_value(self) -> &'static str
pub fn metadata_format_value(self) -> &'static str
Get the format value as it should be stored in the MBTiles metadata table
pub fn content_type(&self) -> &str
Sourcepub fn from_content_type(supertype: &str, subtype: &str) -> Option<Self>
pub fn from_content_type(supertype: &str, subtype: &str) -> Option<Self>
Parse a content type string back to a Format.
pub fn is_detectable(self) -> bool